// ***************************************************************************
// cartridge
// ***************************************************************************
// This file was developed by Prof. Dr. Peer Johannsen as part of the 
// "Retro-Programming" and "Advanced C Programming" class at
// Pforzheim University, Germany.
// 
// It can freely be used, but at one's own risk and for non-commercial
// purposes only. Please respect the copyright and credit the origin of
// this file.
//
// Feedback, suggestions and bug-reports are welcome and can be sent to:
// peer.johannsen@pforzheim-university.de
// ---------------------------------------------------------------------------

#include <vectrex.h>

// ---------------------------------------------------------------------------
// vectrex cartridge init block 

struct cartridge_t
{
	char copyright[11];			// copyright string, must start with "g GCE" and must end with "\x80"
	const void* music;			// 16 bit memory adress of title music data
	signed int title_height;	// signed 8 bit value, height of game title letters
	unsigned int title_width;	// unsigned 8 bit value, width of game title letters
	int title_y;				// signed 8 bit value, y coordinate of game title
	int title_x;				// signed 8 bit value, x coordinate of game title
	char title[20]; 				// game title string, must end with "\x80\x00"
	signed int version_height;	
	unsigned int version_width;	
	int version_y;			
	int version_x;			
	char version[8]; 			
	signed int portby_height;	
	unsigned int portby_width;	
	int portby_y;				
	int portby_x;				
	char portby[16]; 			
	signed int name_height;	
	unsigned int name_width;	
	int name_y;				
	int name_x;				
	char name[]; 				
};

// ---------------------------------------------------------------------------
// edit here to set game title

const struct cartridge_t game_header __attribute__((section(".cartridge"), used)) = 
{
	.copyright 		= "g GCE 2020\x80",	// change year if neccessary, do not change "g GCE"
	.music 			= &Vec_Music_1,		// taken from included headers
	.title_height 	= -8,
	.title_width 	= 80,
	.title_y 		= 64,
	.title_x 		= -110,
	.title 			= "OREGON TRAIL (1978)\x80",
	.version_height 	= -8,
	.version_width 	= 80,
	.version_y 		= 48,
	.version_x 		= -110,
	.version 			= "V 1.0.4\x80",
	.portby_height 	= -8,
	.portby_width 	= 80,
	.portby_y 		= 0,
	.portby_x 		= -90,
	.portby 			= "VECTREX PORT BY\x80",
	.name_height 	= -8,
	.name_width 	= 80,
	.name_y 		= -16,
	.name_x 		= -80,
	.name 			= "RALF KORNMANN\x80"	// note that \x00 is automatically appended!
};

// ***************************************************************************
// end of file
// ***************************************************************************
